tracer

package module
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 10, 2023 License: MIT Imports: 3 Imported by: 0

README

tracer

GoDoc

tracer is a http middleware that uses OpenTelemetry to send trace data to Cloud Trace. It configures OpenTelemetry to propagate traces across application boundaries, adds read/write events, and provides a default span name based upon request URL.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewHandler

func NewHandler(o ...otelhttp.Option) func(http.Handler) http.Handler

NewHandler instanciates a new tracer HTTP handler.

Types

This section is empty.

Jump to